from django.urls import include, path
from django.views.generic import RedirectView

from servala.frontend import views

urlpatterns = [
    path("accounts/profile/", views.ProfileView.as_view(), name="profile"),
    path("accounts/logout/", views.LogoutView.as_view(), name="logout"),
    path(
        "organizations/create",
        views.OrganizationCreateView.as_view(),
        name="organization.create",
    ),
    path(
        "org/<slug:organization>/",
        include(
            [
                path(
                    "details/",
                    views.OrganizationUpdateView.as_view(),
                    name="organization.details",
                ),
                path(
                    "services/",
                    views.ServiceListView.as_view(),
                    name="organization.services",
                ),
                path(
                    "services/<slug:slug>/",
                    views.ServiceDetailView.as_view(),
                    name="organization.service",
                ),
                path(
                    "services/<slug:slug>/offering/<int:pk>/",
                    views.ServiceOfferingDetailView.as_view(),
                    name="organization.offering",
                ),
                path(
                    "",
                    views.OrganizationDashboardView.as_view(),
                    name="organization.dashboard",
                ),
                path(
                    "instances/",
                    views.ServiceInstanceListView.as_view(),
                    name="organization.instances",
                ),
                path(
                    "instances/<slug:slug>/",
                    views.ServiceInstanceDetailView.as_view(),
                    name="organization.instance",
                ),
            ]
        ),
    ),
    path("", RedirectView.as_view(pattern_name="frontend:profile"), name="index"),
]
